@@ -39,6 +39,11 @@ class Bundler(object):
     def literal_representer(dumper, data):
         return dumper.represent_scalar(u"tag:yaml.org,2002:str", data, style="|")
 
+    @staticmethod
+    def yaml_key_mapping(self, node, deep=False):
+        data = self.construct_mapping_org(node, deep)
+        return {(str(key) if isinstance(key, int) else key): data[key] for key in data}
+
     def __init__(self, api_files, output_dir="./"):
         self._parsers = {}
         self._api_files = api_files
@@ -50,6 +55,8 @@ class Bundler(object):
         self._includes = {}
         self._resolved = []
         yaml.add_representer(Bundler.description, Bundler.literal_representer)
+        yaml.SafeLoader.construct_mapping_org = yaml.SafeLoader.construct_mapping
+        yaml.SafeLoader.construct_mapping = Bundler.yaml_key_mapping
 
     def _get_parser(self, pattern):
         if pattern not in self._parsers:
@@ -77,13 +84,15 @@ class Bundler(object):
         self._resolve_x_include()
         self._resolve_x_pattern("x-field-pattern")
         self._resolve_x_constraint()
+        self._resolve_x_status()
         self._remove_x_include()
+        self._resolve_license()
         self._resolve_strings(self._content)
         with open(self._output_filename, "w") as fp:
             yaml.dump(self._content, fp, indent=2, allow_unicode=True, line_break="\n", sort_keys=False)
-        self._validate_file()
         with open(self._json_filename, "w") as fp:
             fp.write(json.dumps(self._content, indent=4))
+        self._validate_file()
 
     def _validate_file(self):
         print("validating {}...".format(self._output_filename))
@@ -114,6 +123,7 @@ class Bundler(object):
                     self._content[key] = {"responses": {}, "schemas": {}}
                 self._validate_names("^[+a-zA-Z0-9_]+$", "schemas", value)
                 self._validate_names("^[+a-zA-Z0-9_]+$", "responses", value)
+                self._check_nested_components(value)
         self._resolve_refs(base_dir, yobject)
 
     def _validate_names(self, regex, components_key, components):
@@ -127,6 +137,21 @@ class Bundler(object):
                         raise NameError("%s property name `%s` contains invalid characters" % (key, name))
             self._content["components"][components_key][key] = value
 
+    def _check_nested_components(self, components):
+        objects = components["schemas"]
+        errors = []
+        for component_name, component_value in objects.items():
+            if "properties" in component_value:
+                component_properties = component_value["properties"]
+                for property_name in component_properties:
+                    property_obj = component_properties[property_name]
+                    if "type" in property_obj:
+                        proprty_type = property_obj["type"]
+                        if proprty_type == "object":
+                            errors.append(f" \n*** Unsupported. Property '{component_name}'.'{property_name}' is a nested component ***")
+        if len(errors) > 0:
+            raise TypeError(''.join(errors))
+
     def _resolve_refs(self, base_dir, yobject):
         """Resolving references is relative to the current file location"""
         if isinstance(yobject, dict):
@@ -199,9 +224,24 @@ class Bundler(object):
             "type": "object",
             "required": ["choice"],
             "properties": {
-                "choice": {"description": "The type of checksum", "type": "string", "enum": ["generated", "custom"], "default": "generated"},
-                "generated": {"description": "A system generated checksum value", "type": "string", "enum": ["good", "bad"], "default": "good"},
-                "custom": {"description": "A custom checksum value", "type": "integer", "minimum": 0, "maximum": 2 ** int(xpattern.get("length", 8)) - 1},
+                "choice": {
+                    "description": "The type of checksum",
+                    "type": "string",
+                    "enum": ["generated", "custom"],
+                    "default": "generated",
+                },
+                "generated": {
+                    "description": "A system generated checksum value",
+                    "type": "string",
+                    "enum": ["good", "bad"],
+                    "default": "good",
+                },
+                "custom": {
+                    "description": "A custom checksum value",
+                    "type": "integer",
+                    "minimum": 0,
+                    "maximum": 2 ** int(xpattern.get("length", 8)) - 1,
+                },
             },
         }
         self._content["components"]["schemas"][schema_name] = schema
@@ -249,8 +289,12 @@ class Bundler(object):
             }
             if "features" in xpattern and "count" in xpattern["features"]:
                 counter_schema["properties"]["count"] = {"type": "integer", "default": 1}
-            self._apply_common_x_field_pattern_properties(counter_schema["properties"]["start"], xpattern, format, property_name="start")
-            self._apply_common_x_field_pattern_properties(counter_schema["properties"]["step"], xpattern, format, property_name="step")
+            self._apply_common_x_field_pattern_properties(
+                counter_schema["properties"]["start"], xpattern, format, property_name="start"
+            )
+            self._apply_common_x_field_pattern_properties(
+                counter_schema["properties"]["step"], xpattern, format, property_name="step"
+            )
             if xconstants is not None:
                 counter_schema["x-constants"] = copy.deepcopy(xconstants)
             self._content["components"]["schemas"][counter_pattern_name] = counter_schema
@@ -308,6 +352,24 @@ class Bundler(object):
                 if pieces[-1] in content:
                     del content[pieces[-1]]
 
+    def _resolve_x_status(self):
+        """Find all instances of x-constraint in the openapi content
+        and merge the x-constraint content into the parent object description
+        """
+        import jsonpath_ng
+
+        for xstatus in self._get_parser("$..x-status").find(self._content):
+            if xstatus.value == "current":
+                continue
+            print("resolving %s..." % (str(xstatus.full_path)))
+            parent_schema_object = jsonpath_ng.Parent().find(xstatus)[0].value
+            if "description" not in parent_schema_object:
+                parent_schema_object["description"] = "TBD"
+            parent_schema_object["description"] = "Status: {status}\n{description}".format(
+                status=xstatus.value,
+                description=parent_schema_object["description"],
+            )
+
     def _resolve_x_constraint(self):
         """Find all instances of x-constraint in the openapi content
         and merge the x-constraint content into the parent object description
@@ -374,6 +436,15 @@ class Bundler(object):
                 descr = copy.deepcopy(value)
                 content[key] = Bundler.description(descr)
 
+    def _resolve_license(self):
+        """License object is not required by the OpenAPI spec.
+        If the license object is provided then name is a required property.
+        """
+        if "license" not in self._content["info"]:
+            self._content["info"]["license"] = {"name": "NO-LICENSE-PRESENT"}
+        elif "name" not in self._content["info"]["license"]:
+            raise Exception("The following properties are REQUIRED: license.name")
+
 
 if __name__ == "__main__":
     Bundler(api_files=["./tests/api/api.yaml"]).bundle()
