@@ -59,7 +59,11 @@ def api(location=None, verify=True, logger=None, loglevel=logging.INFO, ext=None
 class HttpTransport(object):
     def __init__(self, **kwargs):
         """Use args from api() method to instantiate an HTTP transport"""
-        self.location = kwargs["location"] if "location" in kwargs else "https://localhost"
+        self.location = (
+            kwargs["location"]
+            if "location" in kwargs and kwargs["location"] is not None
+            else "https://localhost:443"
+        )
         self.verify = kwargs["verify"] if "verify" in kwargs else False
         self.logger = kwargs["logger"] if "logger" in kwargs else None
         self.loglevel = kwargs["loglevel"] if "loglevel" in kwargs else logging.DEBUG
@@ -384,6 +388,8 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
             if isinstance(value, (OpenApiObject, OpenApiIter)):
                 output[key] = value._encode()
             elif value is not None:
+                if key in self._TYPES and "format" in self._TYPES[key] and self._TYPES[key]["format"] == "int64":
+                    value = str(value)
                 output[key] = value
         return output
 
@@ -395,6 +401,8 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
                     child = self._get_child_class(property_name)
                     if "choice" in child[1]._TYPES and "_parent" in child[1].__slots__:
                         property_value = child[1](self, property_name)._decode(property_value)
+                    elif "_parent" in child[1].__slots__:
+                        property_value = child[1](self)._decode(property_value)
                     else:
                         property_value = child[1]()._decode(property_value)
                 elif isinstance(property_value, list) and property_name in self._TYPES and self._TYPES[property_name]["type"] not in dtypes:
@@ -408,6 +416,8 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
                     if isinstance(self._DEFAULTS[property_name], tuple(dtypes)):
                         property_value = self._DEFAULTS[property_name]
                 self._set_choice(property_name)
+                if "format" in self._TYPES[property_name] and self._TYPES[property_name]["format"] == "int64":
+                    property_value = int(property_value)
                 self._properties[property_name] = property_value
             self._validate_types(property_name, property_value)
         self._validate_required()
